<?php
namespace MASCOTCOREFINANSICO\CPT\Services\Shortcodes;

use MASCOTCOREFINANSICO\Lib;
use MASCOTCOREFINANSICO\CPT\Services\CPT_Services;

/**
 * class SC_Services
 * @package MASCOTCOREFINANSICO\CPT\Services\Shortcodes;
 */
class SC_Services implements Lib\Mascot_Core_Finansico_Interface_PTShortcodes {
	
	/**
	 * @var string
	 */
	private $base;

	/**
	 * construct
	 */
	public function __construct() {
		if ( class_exists( 'ReduxFramework' ) ) {
			if( ! mascot_core_finansico_get_redux_option( 'cpt-settings-services-enable', true ) ) {
				return;
			}
		}
		$this->base = 'tmvc_services';
		add_action('init', array($this, 'vcMap'), 998);
	}

	/**
	 * Returns base for shortcode
	 * @return string
	 */
	public function getBase() {
		return $this->base;
	}



	/**
	 * Maps shortcode to Visual Composer
	 *
	 * @see vc_map()
	 */
	public function vcMap() {
		if(function_exists('vc_map')) {
			$group_content_options = esc_html__( 'Content', 'mascot-core' );
			$group_carousel_options = esc_html__( 'Carousel', 'mascot-core' );
			$group_query_options = esc_html__( 'Query', 'mascot-core' );
			$group_button_options = esc_html__( 'Button', 'mascot-core' );
			$group_loadmore_button_options = esc_html__( 'Loadmore Button', 'mascot-core' );
			$new_cpt_class = CPT_Services::Instance();
			$categories_array = mascot_core_finansico_category_list_array_for_vc( $new_cpt_class->ptTaxKey );

			$orderby_parameters_list = mascot_core_finansico_orderby_parameters_list();


			$vc_map = array(
				'name'		=> esc_html__( 'Services', 'mascot-core' ),
				'base'		=>$this->base,
				'category'	=> 'by TM',
				'description' => esc_html__( 'Services Grid/Carousel', 'mascot-core' ),
				'icon'		=> 'mascot-vc-icons vc-icon-services',
				'allowed_container_element' => 'vc_row',
				'params'	=>array(
					array(
						'type'			=> 'textfield',
						"heading"		=> esc_html__( "Custom CSS class", 'mascot-core' ),
						"param_name"	=> "custom_css_class",
						"description"	=> esc_html__( 'To style particular content element.', 'mascot-core' ),
					),
					array(
						'type'			=> 'dropdown',
						"heading"		=> esc_html__( "Design Style", 'mascot-core' ),
						"param_name"	=> "design_style",
						"description"	=> "",
						'value'			=> array(
							esc_html__( 'Style 1 - Default', 'mascot-core' )	=> 'services-style1-simple',
							esc_html__( 'Style 2 - Classic', 'mascot-core' )	=> 'services-style2-classic',
							esc_html__( 'Style 3 - Modern', 'mascot-core' )		=> 'services-style3-modern',
							esc_html__( 'Style 4 - Round Thumb', 'mascot-core' )		=> 'services-style4-round-thumb',
							esc_html__( 'Style 5 - Hanging Thumb', 'mascot-core' )		=> 'services-style5-hanging-thumb',
							esc_html__( 'Style 6 - Current Theme', 'mascot-core' )	=> 'services-style6-current-theme',
						),
						'save_always'   => true,
						'admin_label'   => true,
					),
					array(
						'type'			=> 'dropdown',
						"heading"		=> esc_html__( "Display Type", 'mascot-core' ),
						"param_name"	=> "display_type",
						"description"	=> "",
						'value'			=> array(
							esc_html__( 'Grid', 'mascot-core' )		=> 'grid',
							esc_html__( 'Masonry', 'mascot-core' )	=> 'masonry',
							esc_html__( 'Carousel', 'mascot-core' )	=> 'carousel'
						),
						'save_always'   => true,
						'admin_label'   => true,
					),
					array(
						'type'			=> 'dropdown',
						"heading"		=> esc_html__( "Columns Layout", 'mascot-core' ),
						"param_name"	=> "columns",
						"description"	=> esc_html__( 'Define Columns Layout for Grid/Carousel.', 'mascot-core' ),
						'value'			=> array(
							'1'  =>  '1',
							'2'  =>  '2',
							'3'  =>  '3',
							'4'  =>  '4',
							'5'  =>  '5',
							'6'  =>  '6',
						),
						'std'			=> 3,
						'save_always'   => true,
						'admin_label'   => true,
					),



					//Carousel Options
					mascot_core_finansico_get_owl_carousel_arraylist( 1, $group_carousel_options, '', array('element' => 'display_type', 'value' => array( 'carousel' ) ) ),
					mascot_core_finansico_get_owl_carousel_arraylist( 2, $group_carousel_options, '', array('element' => 'display_type', 'value' => array( 'carousel' ) ) ),
					mascot_core_finansico_get_owl_carousel_arraylist( 3, $group_carousel_options, '', array('element' => 'display_type', 'value' => array( 'carousel' ) ) ),
					mascot_core_finansico_get_owl_carousel_arraylist( 4, $group_carousel_options, '', array('element' => 'display_type', 'value' => array( 'carousel' ) ) ),
					mascot_core_finansico_get_owl_carousel_arraylist( 5, $group_carousel_options, '', array('element' => 'display_type', 'value' => array( 'carousel' ) ) ),
					mascot_core_finansico_get_owl_carousel_arraylist( 6, $group_carousel_options, '', array('element' => 'display_type', 'value' => array( 'carousel' ) ) ),
					mascot_core_finansico_get_owl_carousel_arraylist( 7, $group_carousel_options, '', array('element' => 'display_type', 'value' => array( 'carousel' ) ) ),
					mascot_core_finansico_get_owl_carousel_arraylist( 8, $group_carousel_options, '', array('element' => 'display_type', 'value' => array( 'carousel' ) ) ),
					mascot_core_finansico_get_owl_carousel_arraylist( 9, $group_carousel_options, '', array('element' => 'display_type', 'value' => array( 'carousel' ) ) ),
					mascot_core_finansico_get_owl_carousel_arraylist( 10, $group_carousel_options, '', array('element' => 'display_type', 'value' => array( 'carousel' ) ) ),
					mascot_core_finansico_get_owl_carousel_arraylist( 11, $group_carousel_options, '', array('element' => 'display_type', 'value' => array( 'carousel' ) ) ),
					mascot_core_finansico_get_owl_carousel_arraylist( 12, $group_carousel_options, '', array('element' => 'display_type', 'value' => array( 'carousel' ) ) ),


					//Query Options
					array(
						'type'			=> 'textfield',
						"heading"		=> esc_html__( "Number of Items to Query from Database", 'mascot-core' ),
						"param_name"	=> "total_items",
						"description"	=> esc_html__( 'How many items do you wish to show? Put -1 to show all. Default 3', 'mascot-core' ),
						'value'			=> 3,
						'save_always'   => true,
						'admin_label'   => true,
						'group'			=> $group_query_options
					),
					array(
						'type'			=> 'checkbox',
						"heading"		=> esc_html__( "Category", 'mascot-core' ),
						"param_name"	=> "selected_category",
						"description"	=> esc_html__( 'Choose a category to pull services from.', 'mascot-core' ),
						'value'			=> $categories_array,
						'group'			=> $group_query_options
					),
					array(
						'type'			=> 'dropdown',
						"heading"		=> esc_html__( "Order By", 'mascot-core' ),
						"param_name"	=> "order_by",
						"description"	=> esc_html__( 'Select how to sort retrieved posts.', 'mascot-core' ),
						'value'			=> $orderby_parameters_list,
						'std'			=> $orderby_parameters_list[ 'Date' ],
						'group'			=> $group_query_options
					),
					array(
						'type'			=> 'dropdown',
						"heading"		=> esc_html__( "Order", 'mascot-core' ),
						"param_name"	=> "order",
						"description"	=> esc_html__( 'Descending or Ascending order.', 'mascot-core' ),
						'value'			=> array(
							esc_html__( 'Descending', 'mascot-core' )	=> 'DESC',
							esc_html__( 'Ascending', 'mascot-core' )	=> 'ASC',
						),
						'group'			=> $group_query_options
					),



					//Content Options
					
					//Category Filter
					mascot_core_finansico_get_cat_filter_arraylist( 1, $group_content_options, array('element' => 'display_type', 'value' => array('grid', 'masonry', 'carousel') ) ),
					mascot_core_finansico_get_cat_filter_arraylist( 2, $group_content_options ),
					mascot_core_finansico_get_cat_filter_arraylist( 3, $group_content_options ),
					mascot_core_finansico_get_cat_filter_arraylist( 4, $group_content_options ),
					
					array(
						'type'			=> 'checkbox',
						"heading"		=> esc_html__( "Add Border Radius Around the Box", 'mascot-core' ),
						"param_name"	=> "add_border_radius",
						'admin_label'   => true,
						'group'			=> $group_content_options
					),
					array(
						'type'			=> 'textfield',
						"heading"		=> esc_html__( "Custom Border Radius", 'mascot-core' ),
						"param_name"	=> "custom_border_radius",
						"description"	=> esc_html__( 'Example: 15px 10px 15px 10px', 'mascot-core' ),
						'dependency'	=> array('element' => 'add_border_radius', 'value' => 'true'),
						'group'			=> $group_content_options
					),
					array(
						'type'			=> 'dropdown',
						"heading"		=> esc_html__( "Show Title", 'mascot-core' ),
						"param_name"	=> "show_title",
						'description'   => '',
						'value'			=> array(
							esc_html__( 'Yes', 'mascot-core' )	=> 'true',
							esc_html__( 'No', 'mascot-core' )	=> 'false'
						),
						'admin_label'   => true,
						'group'			=> $group_content_options
					),
					array(
						'type'			=> 'dropdown',
						"heading"		=> esc_html__( "Title Tag", 'mascot-core' ),
						"param_name"	=> "title_tag",
						"description"	=> "",
						'value'			=> mascot_core_finansico_heading_tag_list(),
						'std'			=> 'h5',
						'dependency'	=> array('element' => 'show_title', 'value' => 'true'),
						'admin_label'   => true,
						'save_always'   => true,
						'group'			=> $group_content_options
					),
					array(
						'type'			=> 'dropdown',
						"heading"		=> esc_html__( "Show Excerpt", 'mascot-core' ),
						"param_name"	=> "show_excerpt",
						'description'   => '',
						'value'			=> array(
							esc_html__( 'Yes', 'mascot-core' )	=> 'true',
							esc_html__( 'No', 'mascot-core' )	=> 'false'
						),
						'admin_label'   => true,
						'group'			=> $group_content_options
					),
					array(
						'type'			=> 'textfield',
						"heading"		=> esc_html__( "Excerpt Length", 'mascot-core' ),
						"param_name"	=> "excerpt_length",
						"description"	=> esc_html__( 'Number of words to display. Example: 25. Default all.', 'mascot-core' ),
						'dependency'	=> array('element' => 'show_excerpt', 'value' => 'true'),
						'group'			=> $group_content_options
					),
					array(
						'type'			=> 'dropdown',
						"heading"		=> esc_html__( "Show Thumbnail", 'mascot-core' ),
						"param_name"	=> "show_thumb",
						'description'   => '',
						'value'			=> array(
							esc_html__( 'Yes', 'mascot-core' )	=> 'true',
							esc_html__( 'No', 'mascot-core' )	=> 'false'
						),
						'admin_label'   => true,
						'group'			=> $group_content_options
					),
					array(
						'type'			=> 'dropdown',
						"heading"		=> esc_html__( "Thumbnail Image Size", 'mascot-core' ),
						"param_name"	=> "feature_thumb_image_size",
						'description'   => '',
						'value'			=> mascot_core_finansico_get_available_image_sizes_for_vc(),
						'std'			=> 'post-thumbnail',
						'save_always'   => true,
						'admin_label'   => true,
						'dependency'	=> array('element' => 'show_thumb', 'value' => 'true'),
						'group'			=> $group_content_options
					),




					
					//Button
					mascot_core_finansico_get_viewdetails_button_arraylist( 1, $group_button_options ),
					mascot_core_finansico_get_viewdetails_button_arraylist( 2, $group_button_options ),

					//Button options
					mascot_core_finansico_get_button_arraylist( 1, $group_button_options ),
					mascot_core_finansico_get_button_arraylist( 2, $group_button_options ),
					mascot_core_finansico_get_button_arraylist( 3, $group_button_options ),
					mascot_core_finansico_get_button_arraylist( 4, $group_button_options ),
					mascot_core_finansico_get_button_arraylist( 5, $group_button_options ),
					mascot_core_finansico_get_button_arraylist( 6, $group_button_options ),
					mascot_core_finansico_get_button_arraylist( 7, $group_button_options ),
					mascot_core_finansico_get_button_arraylist( 8, $group_button_options ),
					mascot_core_finansico_get_button_arraylist( 9, $group_button_options ),

					//Loadmore Button options
					mascot_core_finansico_get_viewdetails_button_arraylist( 1, $group_loadmore_button_options,  esc_html__( "Load More", 'mascot-core' ), 'loadmore_', 'false' ),
					mascot_core_finansico_get_viewdetails_button_arraylist( 2, $group_loadmore_button_options,  esc_html__( "Load More", 'mascot-core' ), 'loadmore_', 'false' ),
					$array = array(
						'type'			=> 'textfield',
						"heading"		=> esc_html__( "Loading Text", 'mascot-core' ),
						"param_name"	=> "loadmore_button_loading_text",
						'std'			=> esc_html__( "Loading...", 'mascot-core' ),
						'save_always'   => true,
						'group'			=> $group_loadmore_button_options
					),
					mascot_core_finansico_get_button_arraylist( 1, $group_loadmore_button_options, 'loadmore_' ),
					mascot_core_finansico_get_button_arraylist( 2, $group_loadmore_button_options, 'loadmore_' ),
					mascot_core_finansico_get_button_arraylist( 3, $group_loadmore_button_options, 'loadmore_' ),
					mascot_core_finansico_get_button_arraylist( 4, $group_loadmore_button_options, 'loadmore_' ),
					mascot_core_finansico_get_button_arraylist( 5, $group_loadmore_button_options, 'loadmore_' ),
					mascot_core_finansico_get_button_arraylist( 6, $group_loadmore_button_options, 'loadmore_' ),
					mascot_core_finansico_get_button_arraylist( 7, $group_loadmore_button_options, 'loadmore_' ),
					mascot_core_finansico_get_button_arraylist( 8, $group_loadmore_button_options, 'loadmore_' ),
					mascot_core_finansico_get_button_arraylist( 9, $group_loadmore_button_options, 'loadmore_' ),

					mascot_core_finansico_vc_add_css_editor(),
					

				)
			);
			vc_map( $vc_map );

			//Modify vc_map from themes
			if( function_exists('mascot_core_finansico_cpt_sc_services_vc_map_modifier') ) {
				mascot_core_finansico_cpt_sc_services_vc_map_modifier( $this->base );
			}
		}
	}

	/**
	 * Renders shortcodes HTML
	 *
	 * @param $attr array of shortcode params
	 * @param $content string shortcode content
	 * @return string
	 */
	public function render( $attr, $content = null ) {
		if ( class_exists( 'ReduxFramework' ) ) {
			if( ! mascot_core_finansico_get_redux_option( 'cpt-settings-services-enable', true ) ) {
				return;
			}
		}

		//Render Shortcode from themes
		if( function_exists('mascot_core_finansico_cpt_sc_services_render') && function_exists('vc_map') ) {
			return mascot_core_finansico_cpt_sc_services_render( $attr, $content, CPT_Services::Instance() );
		}
		
	}
}